@@ -4,7 +4,7 @@ import sys
 import json
 import base64
 import logging
-from io import BytesIO
+
 from pathlib import Path
 from functools import wraps
 from datetime import datetime
@@ -16,10 +16,7 @@ from werkzeug._internal import _wsgi_encoding_dance, _to_bytes  # noqa
 from .safe_exception_handler import SafeExceptionReporterFilter
 from jinja2 import Environment, select_autoescape, FileSystemLoader
 
-PATH = os.path.dirname(os.path.abspath(__file__))
-PATH = os.path.join(PATH, 'templates')
-print(PATH)
-templateEnv = Environment(loader=FileSystemLoader(PATH),
+templateEnv = Environment(loader=FileSystemLoader(Path(__file__).parent / 'templates'),
                           autoescape=select_autoescape())
 
 templateEnv.filters["pprint"] = pprint
@@ -61,16 +58,16 @@ class ExceptionReporter:
                 'QUERY_STRING': unquote(parsed_url.query),
                 'REMOTE_ADDR': event.get('x-real-ip', ''),
                 'REQUEST_METHOD': event.get('method', 'GET'),
-                'SCRIPT_NAME': '',
                 'SERVER_NAME': headers.get('host', 'lambda'),
                 'SERVER_PORT': headers.get('x-forwarded-port', '443'),
                 'SERVER_PROTOCOL': 'HTTP/2',
-                'wsgi.input': BytesIO(body).read().decode('utf-8'),
+                'BODY': body.decode('utf-8'),
                 'wsgi.multiprocess': False,
                 'wsgi.multithread': False,
                 'wsgi.run_once': False,
                 'wsgi.url_scheme': headers.get('x-forwarded-proto', 'https'),
                 'wsgi.version': (1, 0),
+                'HEADERS': event.get('headers', None),
             }
 
             for key, value in environ.items():
